@@ -1,6 +1,7 @@
 from .....core import BaseAnalyzer, Validator, Required
 from .....taxonomies import Taxonomy
-from .....config.consts import CONFIG_TAXONOMY_ID, CONFIG_TAXONOMY_CT, CONFIG_TAXONOMY_SETTINGS
+from .....config.consts import CONFIG_TAXONOMY_ID, CONFIG_TAXONOMY_CT, CONFIG_TAXONOMY_SETTINGS,\
+    CONFIG_TAXONOMY_MISSING_VALUES
 
 
 class TaxonomyFetcherAnalyzer(BaseAnalyzer):
@@ -14,6 +15,7 @@ class TaxonomyFetcherAnalyzer(BaseAnalyzer):
         t: Taxonomy = self.context.taxonomies.get(tid)
         self.config[CONFIG_TAXONOMY_CT] = t.column_types
         self.config[CONFIG_TAXONOMY_SETTINGS] = t.config
+        self.config[CONFIG_TAXONOMY_MISSING_VALUES] = t.missingValues
 
     def analyze(self):
         if self.test():
